Name:           Ray
Version:        2.3.1
Release:        12%{?dist}
Summary:        Parallel genome assemblies for parallel DNA sequencing

Group:          Applications/Engineering
License:        GPLv3
URL:            http://denovoassembler.sourceforge.net/
Source0:        http://downloads.sourceforge.net/denovoassembler/%{name}-%{version}.tar.bz2
Patch0:         Ray.manpage.patch
Patch1:         pthread.patch

%global useMpich 1
%ifarch ppc64
%if 0%{?rhel}==5 || 0%{?rhel} == 6
%global useMpich 0
%endif
%endif

%define mpichName mpich

# el5 still uses the old name MPICH2
%if 0%{?rhel}==5
    %define mpichName mpich2
%endif

BuildRequires:  openmpi-devel, bzip2-devel, zlib-devel

%if %useMpich
BuildRequires:  %{mpichName}-devel
%endif

%description
%{name} is a parallel software that computes de novo genome assemblies with   
next-generation sequencing data.
%{name} is written in C++ and can run in parallel on numerous interconnected 
computers using the message-passing interface (MPI) standard.
Included:
 - %{name} de novo assembly of single genomes
 - %{name} Méta de novo assembly of metagenomes
 - %{name} Communities microbe abundance + taxonomic profiling
 - %{name} Ontologies gene ontology profiling

%package common
Summary:        Parallel genome assemblies for parallel DNA sequencing
Group:          Applications/Engineering

%description common
%{name} is a parallel software that computes de novo genome assemblies with   
next-generation sequencing data.
%{name} is written in C++ and can run in parallel on numerous interconnected 
computers using the message-passing interface (MPI) standard.
This sub-package contains common files for Ray.

%package openmpi
Summary:        %{name} package for Open-MPI
Group:          Applications/Engineering
Requires:       %{name}-common

%description openmpi
%{name} is a parallel software that computes de novo genome assemblies with   
next-generation sequencing data.
%{name} is written in C++ and can run in parallel on numerous interconnected 
computers using the message-passing interface (MPI) standard.
This sub-package enables parallel computation using openmpi.


%if %useMpich
%package %{mpichName}
Summary:        %{name} package for MPICH
Group:          Applications/Engineering
Requires:       %{name}-common
%if %{mpichName} == "mpich"
Obsoletes:      %{name}-mpich2 < 2.3.1-4
Conflicts:      %{name}-mpich2 < 2.3.1-4
%endif

%description %{mpichName}
%{name} is a parallel software that computes de novo genome assemblies with   
next-generation sequencing data.
%{name} is written in C++ and can run in parallel on numerous interconnected 
computers using the message-passing interface (MPI) standard.
This sub-package enables parallel computation using mpich.
%endif

%package doc
Summary:        Documentation files
Group:          Documentation
Requires:       %{name}-common

%description doc
%{name} is a parallel software that computes de novo genome assemblies with   
next-generation sequencing data.
%{name} is written in C++ and can run in parallel on numerous interconnected 
computers using the message-passing interface (MPI) standard.
This sub-package includes documentation files.

%package extra
Summary:        Scripts and XSL sheets for post-processing
Group:          Applications/Engineering
Requires:       python, R, %{name}-common

%description extra
%{name} is a parallel software that computes de novo genome assemblies with   
next-generation sequencing data.
%{name} is written in C++ and can run in parallel on numerous interconnected 
computers using the message-passing interface (MPI) standard.
This sub-package contains scripts and XSL sheets for post-processing.

%prep
%setup -q -n %{name}-%{version}
%patch0
%patch1

%build
CXXFLAGS="%{optflags}"

%{_openmpi_load}
make CXXFLAGS="$CXXFLAGS" HAVE_LIBBZ2=y HAVE_LIBZ=y Q=
cp %{name} %{name}$MPI_SUFFIX

cp README.md README
cp %{name}Platform/README.md README.%{name}Platform
cp %{name}Platform/AUTHORS AUTHORS.%{name}Platform

make clean
%{_openmpi_unload}

%if %useMpich
    # %{_%{mpichName}_load} does not work
    %if %mpichName == "mpich"
        %{_mpich_load}
    %else
        %{_mpich2_load}
    %endif
make CXXFLAGS="$CXXFLAGS" HAVE_LIBBZ2=y HAVE_LIBZ=y Q=
cp %{name} %{name}$MPI_SUFFIX
make clean
    %if %mpichName == "mpich"
        %{_mpich_unload}
    %else
        %{_mpich2_unload}
    %endif
%endif

%install
rm -rf %{buildroot}

# Ray-common
mkdir -p %{buildroot}%{_mandir}/man1
install -m 0644 %{name}.1 %{buildroot}%{_mandir}/man1/%{name}.1

# Ray-openmpi
%{_openmpi_load}
mkdir -p %{buildroot}$MPI_BIN
install -m 0755 %{name}$MPI_SUFFIX %{buildroot}$MPI_BIN
%{_openmpi_unload}

%if %useMpich
# Ray-mpich
    %if %mpichName == "mpich"
        %{_mpich_load}
    %else
        %{_mpich2_load}
    %endif
mkdir -p %{buildroot}$MPI_BIN
install -m 0755 %{name}$MPI_SUFFIX %{buildroot}$MPI_BIN
    %if %mpichName == "mpich"
        %{_mpich_unload}
    %else
        %{_mpich2_unload}
    %endif
%endif

# Ray-doc
mkdir doc
cp -ar %{name}Platform/Documentation/ doc/%{name}Platform
chmod 644 doc/%{name}Platform/*
chmod 644 Documentation/*

# Ray-extra
mkdir -p %{buildroot}%{_datadir}/%{name}
cp -r scripts %{buildroot}%{_datadir}/%{name}
chmod 0755 %{buildroot}%{_datadir}/%{name}/scripts

%clean
rm -rf %{buildroot}

%files common
%doc MANUAL_PAGE.txt gpl-3.0.txt LICENSE.txt 
%doc %{name}Platform/lgpl-3.0.txt
%doc AUTHORS AUTHORS.%{name}Platform
%doc README README.%{name}Platform
%{_mandir}/man1/%{name}.1*

%files openmpi
%{_libdir}/openmpi/bin/%{name}*

%if %useMpich
%files %{mpichName}
%{_libdir}/%{mpichName}/bin/%{name}*
%endif

%files doc
%doc Documentation/*
%doc doc/%{name}Platform/

%files extra
%{_datadir}/%{name}/

%changelog
* Tue Sep 15 2015 Orion Poplawski <orion@cora.nwra.com> - 2.3.1-12
- Rebuild for openmpi 1.10.0

* Sat Aug 15 2015 Zbigniew Jędrzejewski-Szmek <zbyszek@in.waw.pl> - 2.3.1-11
- Rebuild for MPI provides

* Sun Jul 26 2015 Sandro Mani <manisandro@gmail.com> - 2.3.1-10
- Rebuild for RPM MPI Requires Provides Change

* Tue Jun 16 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.3.1-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Sat May 02 2015 Kalev Lember <kalevlember@gmail.com> - 2.3.1-8
- Rebuilt for GCC 5 C++11 ABI change

* Mon Mar 16 2015 Sebastien Boisvert <boisvert@anl.gov> - 2.3.1-7
- fix linking issue in rawhide

* Wed Nov 5 2014 Tuomo Soini <tis@foobar.fi> - 2.3.1-6
- Ray-mpich2 got obsoleted by rhel 6.6 update

* Fri Aug 15 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.3.1-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Fri Jun 06 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.3.1-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Sun Mar 2 2014 Sébastien Boisvert <sebastien.boisvert.3@ulaval.ca> - 2.3.1-3
- use correct macro name to load/unload mpich2

* Mon Feb 24 2014 Sébastien Boisvert <sebastien.boisvert.3@ulaval.ca> - 2.3.1-2
- add a variable for mpich package name (mpich or mpich2)

* Mon Feb 24 2014 Sébastien Boisvert <sebastien.boisvert.3@ulaval.ca> - 2.3.1-1
- Fix days of week in spec changelog (rpmlint warning)
- Update version with upstream.

* Wed Sep 04 2013 Sébastien Boisvert <sebastien.boisvert.3@ulaval.ca> - 2.1.0-8
- Change dependency name from mpich2 to mpich

* Fri Aug 02 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.1.0-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Mon Jul 15 2013 Sébastien Boisvert <sebastien.boisvert.3@ulaval.ca> - 2.1.0-6
- Skip mpich2 on el5 and el6 for ppc64

* Thu Nov 29 2012 Sébastien Boisvert <sebastien.boisvert.3@ulaval.ca> - 2.1.0-5
- Added a patch for the man page

* Mon Nov 5 2012 Sébastien Boisvert <sebastien.boisvert.3@ulaval.ca> - 2.1.0-4
- The man page encoding is en_US.UTF-8
- Added more specific descriptions

* Sun Nov 4 2012 Sébastien Boisvert <sebastien.boisvert.3@ulaval.ca> - 2.1.0-3
- Changed the package name from ray to Ray
- Renamed README.md to README
- Added AUTHORS, README.RayPlatform, AUTHORS.RayPlatform

* Sun Nov 4 2012 Sébastien Boisvert <sebastien.boisvert.3@ulaval.ca> - 2.1.0-2
- Added build dependency help2man 
- Added OMPI_MCA_orte_rsh_agent to pass mock builds

* Sat Nov 3 2012 Sébastien Boisvert <sebastien.boisvert.3@ulaval.ca> - 2.1.0-1

- The Spec file was (informally) reviewed by Jussi Lehtola
- Moved sub-package declarations to the top
- Added sub-packages common, openmpi, mpich2
- Removed useless '/' after buildroot
- Fixed the packaging of Documentation
- Removed symbols that are not U.S. American English from man page
- Added Fedora compilation flags (optflags)
- The Spec file was (informally) reviewed a second time by Jussi Lehtola
- CXXFLAGS was shortened
- Replacement of non-ASCII symbols is more compact with sed
- ray-extra now ships _datadir/ray/ instead of _datadir/ray/scripts/.
- This is the initial Ray package for Fedora
